==> haskell-http-client-restricted-0.1.0-163-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-restricted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-8gPjS0zMVHSALmoKTqT0Io
key:                  http-client-restricted-0.1.0-8gPjS0zMVHSALmoKTqT0Io
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  8b8576b768f2db8ba923b9b1784d0913
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-8gPjS0zMVHSALmoKTqT0Io
depends:
    base-4.17.2.1 crypton-connection-0.4.4-Ab8v787zCCYJ26NhXbMkEl
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM
    http-client-0.7.19-LRfftiQ6YWX88xW4fFXEK8
    http-client-tls-0.3.6.4-3SOG6pMBD126OroBvnbwcp
    network-3.1.4.0-7GxbLibXQB6BN49yptQL65
    network-bsd-2.8.1.0-CawTJYvF4Qd3w2PL2cRFrw
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-restricted-0.1.0-164-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-client-restricted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-client-restricted
version:              0.1.0
visibility:           public
id:                   http-client-restricted-0.1.0-9VRup7tWwuu5ATThNGcmuP
key:                  http-client-restricted-0.1.0-9VRup7tWwuu5ATThNGcmuP
license:              MIT
copyright:            2018 Joey Hess, 2013 Michael Snoyman
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
synopsis:             restricting the servers that http-client will use
description:
    Addition to the http-client and http-client-tls
    libraries, that restricts the HTTP servers that can be used.

    This is useful when a security policy needs to eg, prevent connections to
    HTTP servers on localhost or a local network, or only allow connections
    to a specific HTTP server.

    It handles restricting redirects as well as the initial HTTP connection,
    and it also guards against DNS poisoning attacks.

category:             Network
abi:                  f7ed85e59198bc5416c8177e6db545b8
exposed:              True
exposed-modules:      Network.HTTP.Client.Restricted
import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-client-restricted-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-client-restricted
hs-libraries:         HShttp-client-restricted-0.1.0-9VRup7tWwuu5ATThNGcmuP
depends:
    base-4.17.2.1 crypton-connection-0.4.4-3yZR1YefdB5FRbkCfJg3pE
    data-default-0.7.1.2-2qohbnSvS9oK93FFGOJ5gM
    http-client-0.7.19-B8l1xqF9CzrAQJibWsxIAb
    http-client-tls-0.3.6.4-Egz0XoSYeB1LT6UCJVMaX8
    network-3.1.4.0-KAEk2uZxmO9GA8hoXz0jL7
    network-bsd-2.8.1.0-BJUSKEuJTGy8j4ZDnoY4NB
    utf8-string-1.0.2-EpYvbnx7dwVHTduFVbgaKq

haddock-interfaces:
    /usr/share/doc/haskell-http-client-restricted/html/http-client-restricted.haddock

haddock-html:         /usr/share/doc/haskell-http-client-restricted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
